@@ -4,6 +4,13 @@ implicit double precision(a-h,o-z)
 dimension :: alpha(kstate,n), beta(kstate,n), gamma(kstate,n)
 dimension :: wrk(kstate)
 
+if(n < 2) then
+     call rexit("From gfun --- each series must contain at least two observations.")
+endif
+! We could probably cope with time series that have a single observation, but it
+! would be fiddly and le jeu n'en vaut pas la chandelle.  Actually two is
+! ridiculously small.
+
 zero = 0.d0
 ook  = 1.d0/dble(kstate)
 
